pub struct Camera3D {
pub transform: NodeTransform,
pub fov: f32,
pub is_active: bool,
pub priority: i32,
pub exposure: f32,
/* private fields */
}Expand description
A 3D camera that can be use in a 3d environment.
Fields
transform: NodeTransformthe NodeTransform of the camera (every node has this)
fov: f32the field of view of the camera in radians
is_active: boolpriority: i32exposure: f32Implementations
Sourceimpl Camera3D
impl Camera3D
Sourcepub fn rotate_camera(&mut self, offset: impl Into<Vec3>, sensitivity: f32)
pub fn rotate_camera(&mut self, offset: impl Into<Vec3>, sensitivity: f32)
rotate the camera while keeping the roll at 0
Arguments
offset- The offset to rotate the camera by a 3d vectorsensitivity- The sensitivity of the rotation
Sourcepub fn set_position(&mut self, position: impl Into<Vec3>)
pub fn set_position(&mut self, position: impl Into<Vec3>)
pub fn far_plane(&self) -> f32
pub fn near_plane(&self) -> f32
Sourcepub fn get_position(&self, parent_transform: NodeTransform) -> Vec3
pub fn get_position(&self, parent_transform: NodeTransform) -> Vec3
Sourcepub fn set_orientation_vector(
&mut self,
orientation: impl Into<Vec3>,
) -> &mut Camera3D
pub fn set_orientation_vector( &mut self, orientation: impl Into<Vec3>, ) -> &mut Camera3D
set the orientation vector of the camera
Arguments
orientation- The new orientation vector of the camera
Sourcepub fn get_orientation_vector(&self) -> Vec3
pub fn get_orientation_vector(&self) -> Vec3
Sourcepub fn get_orientation_angles(&self) -> Vec3
pub fn get_orientation_angles(&self) -> Vec3
Sourcepub fn set_orientation_angles(&mut self, angles: impl Into<Vec3>)
pub fn set_orientation_angles(&mut self, angles: impl Into<Vec3>)
set the orientation angles of the camera
Arguments
angles- The new orientation angles of the camera
Sourcepub fn get_view_matrix(&self) -> Mat4
pub fn get_view_matrix(&self) -> Mat4
Sourcepub fn get_projection_matrix(&self, aspect_ratio: f32) -> Mat4
pub fn get_projection_matrix(&self, aspect_ratio: f32) -> Mat4
Sourcepub fn get_projection_matrix_with_planes(
&self,
aspect_ratio: f32,
near: f32,
far: f32,
) -> Mat4
pub fn get_projection_matrix_with_planes( &self, aspect_ratio: f32, near: f32, far: f32, ) -> Mat4
useful for shadow mapping
Sourcepub fn get_vp_matrix(&self, aspect_ratio: f32) -> Mat4
pub fn get_vp_matrix(&self, aspect_ratio: f32) -> Mat4
pub fn get_buffer_data(&self, aspect_ratio: f32) -> Camera3DBufferData
Sourcepub fn free_look(sensitivity: f32) -> impl Fn(EventCtx<'_, Update, Camera3D>)
pub fn free_look(sensitivity: f32) -> impl Fn(EventCtx<'_, Update, Camera3D>)
allows the mouse to rotate the camera in a first person way.
this returns a function that can be used as a event_callback
uses camera.sensitivity to factor the look speed. add this function to the update callback to enable the camera to move with the mouse.
Sourcepub fn free_fly(
speed: f32,
sensitivity: f32,
) -> impl Fn(EventCtx<'_, Update, Camera3D>)
pub fn free_fly( speed: f32, sensitivity: f32, ) -> impl Fn(EventCtx<'_, Update, Camera3D>)
take input for the camera and implement basic free cam movement
this returns a function that can be used as a event_callback
Arguments
input_manager- The input manager to get input fromdelta_time- The time between frames