pub struct DirectionalLightBuilder { /* private fields */ }Expand description
builder implementation for directional lights
Implementations
Sourceimpl DirectionalLightBuilder
impl DirectionalLightBuilder
Sourcepub fn direction(self, direction: impl Into<Vec3>) -> DirectionalLightBuilder
pub fn direction(self, direction: impl Into<Vec3>) -> DirectionalLightBuilder
direction of the lights
the light direction is independent from its rotation
Sourcepub fn color(self, color: impl Into<Vec4>) -> DirectionalLightBuilder
pub fn color(self, color: impl Into<Vec4>) -> DirectionalLightBuilder
color of the light
Sourcepub fn intensity(self, intensity: f32) -> DirectionalLightBuilder
pub fn intensity(self, intensity: f32) -> DirectionalLightBuilder
strength of the light
Sourcepub fn far_plane(self, far_plane: f32) -> DirectionalLightBuilder
pub fn far_plane(self, far_plane: f32) -> DirectionalLightBuilder
how far from the light shadows are rendered from the camera.
default value is 100
Sourcepub fn bias(self, bias: f32) -> DirectionalLightBuilder
pub fn bias(self, bias: f32) -> DirectionalLightBuilder
set the shadow bias
default value is 0.005
Sourcepub fn cascades_level(self, level: usize) -> DirectionalLightBuilder
pub fn cascades_level(self, level: usize) -> DirectionalLightBuilder
set the cascade level of the light for shadow detail at greater distance
level is clamped between 1 and 4