pub struct PointLight {
pub transform: NodeTransform,
pub color: Vec4,
pub bias: f32,
/* private fields */
}Expand description
point lights nodes represent point lights in the Scene
point lights are lights that are cast from a single point. light is calculated by getting the distance and direction to the point light position.
Fields
transform: NodeTransformtransform component for point light
color: Vec4the light color default is White
bias: f32Implementations
Sourceimpl PointLight
impl PointLight
Sourcepub fn new() -> PointLight
pub fn new() -> PointLight
create a point light.
Sourcepub fn get_buffered_data(&self, index: usize) -> PointLightBufferData
pub fn get_buffered_data(&self, index: usize) -> PointLightBufferData
returns the formatted buffer data
Sourcepub fn get_intensity(&self) -> f32
pub fn get_intensity(&self) -> f32
get the nodes intensity
Sourcepub fn get_intensity_mut(&mut self) -> &mut f32
pub fn get_intensity_mut(&mut self) -> &mut f32
get the nodes intensity
Sourcepub fn set_intensity(&mut self, intensity: f32)
pub fn set_intensity(&mut self, intensity: f32)
how strong the light is.
this will also update the far plane for shadows since more intense lights go further
Sourcepub fn calculate_far_plane(intensity: f32, threshold: f32) -> f32
pub fn calculate_far_plane(intensity: f32, threshold: f32) -> f32
calculate the far_plane for a given intensity so that the shadow cutoff is at a light level thrshhold
to save resources we only want to render shadows as far as the light is visible so we can cut it off at a given threshold
pub fn get_shadow_transformations(&self) -> [Mat4; 6]
Sourcepub fn set_color(&mut self, color: impl Into<Vec4>) -> &mut PointLight
pub fn set_color(&mut self, color: impl Into<Vec4>) -> &mut PointLight
set the light color
Sourcepub fn get_color_mut(&mut self) -> &mut Vec4
pub fn get_color_mut(&mut self) -> &mut Vec4
get the light color