the EngineCofig is used to create engine settings before the context is initialized
some things need to be known by the engine beforehand such as the window title or Resolution
Example
use maple::{
Engine,
config::{EngineConfig, Resolution},
};
use std::default::Default;
let engine = Engine::init(EngineConfig {
window_title: "Hello, Window!".to_string(),
resolution: Resolution {
width: 1920,
height: 1080,
},
..Default::default()
});
Structs
- Engine
Config - the config of the engine
- Resolution
- the resolution of the window in pixels
Enums
- Window
Mode - the mode refers to if its fullscreenm borderless or windowed.